function PrctileUnCondMean=EstSummaryMain(estsum,ComputeSteadyState,X,D,Pires,Sigmares,Phires,MeanUpsilon,StdUpsilon,LogMargLike,StructuralForm,K,p,q,lambdas,season,PeriodType,difference,IncludeConstant,ML,estdates,varlabels,dummylabels,MeanFirstLag,OutFileName)

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:          Script file for estimation summaries in BVARs 
%
% AUTHOR:           Mattias Villani, Research Department, Sveriges Riksbank and
%                   Department of Statistics, Stockholm University. 
%                   E-mail: mattias.villani@riksbank.se
%
% FIRST VERSION:    2005-02-23   
% LAST REVISED:     
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Computing the steady state (unconditional mean) of the process
if ComputeSteadyState==1
    UnCondMean=UnCondMeanVAR(Pires,Phires,K,X,D,IncludeConstant,p);
    Niter=size(UnCondMean,3); % number of Gibbs sampling draws.
    for i=difference
        for j=1:Niter
            UnCondMean(:,i,j)=Diff2AnnualDiff(UnCondMean(:,i,j),[],season);
        end
    end
    if size(UnCondMean,3)>1
        Prctiles=[2.5 50 97.5];
        PrctileUnCondMean=prctile(UnCondMean,Prctiles,3);
    else
        PrctileUnCondMean=UnCondMean;
    end
else
    PrctileUnCondMean=nan;
end

% Computes estimates of model parameters
if estsum==1
    if isempty(Phires)
        ModelType='Standard VAR';
    else
        ModelType='Steady State VAR';
    end
    
switch ML
    case 0
        EstMethod='Bayesian Estimation';
    case 1
        EstMethod='Maximum Likelihood Estimation - Unrestricted';
    case 2
        EstMethod='Maximum Likelihood Estimation - BlockFIML';
    case 3
        EstMethod='Maximum Likelihood Estimation - BlockQuasi';
    otherwise
end
    
    
    [P,meansigma]=estsummary(Pires,Sigmares,Phires,MeanUpsilon,StdUpsilon,StructuralForm,K,p);
    fid=fopen(strcat(OutFileName,'_Est','.txt'),'wt'); % Open file to write the results to
    
    DateAndTimeStr=Clock2DateAndTimeStr(clock);     % a string containing current data and time
    fprintf(fid,'\n');
    fprintf(fid,'-------------------------------------------------------------------------------------------------------\n');
    fprintf(fid,'                                  BayesVAR - Summary of Parameter Estimates                            \n');
    fprintf(fid,'                    Author: Mattias Villani, Sveriges Riksbank and Stockholm University                \n');
    fprintf(fid,['                                          ',DateAndTimeStr,'                                          \n']);
    fprintf(fid,'--------------------------------------------------------------------------------------------------------\n');
    fprintf(fid,'\n\n');
    
    % Model info
    fprintf(fid,'%25s\n',[ModelType,' - ',EstMethod]);
    fprintf(fid,'%20s\n',['Estimation period:           ',num2str(estdates(1,2)),PeriodType,num2str(estdates(1,3)),'-',num2str(estdates(end,2)),PeriodType,num2str(estdates(end,3))]); 
    fprintf(fid,'\n');
    fprintf(fid,'%-20s\n','Endogenous Variables and Prior on First Own Lag:');
    for jj=1:length(varlabels)
        fprintf(fid,'%-26s %15.3f\n',varlabels{jj},MeanFirstLag(jj));
    end
    fprintf(fid,'\n');
    fprintf(fid,'%-20s\n','Exogenous Variables:');
    for jj=1:length(dummylabels)
        fprintf(fid,'%-15s\n',dummylabels{jj});
    end
    fprintf(fid,'\n');
    if ML==0
        fprintf(fid,'%-20s\n','Prior: ');
        fprintf(fid,'%15s %15.3f\n','Overall shrinkage:        ',lambdas(1));
        fprintf(fid,'%15s %15.3f\n','Cross-equation shrinkage: ',lambdas(2));
        fprintf(fid,'%15s %15.3f\n','Lag length decay:         ',lambdas(3));
        fprintf(fid,'%15s %15.3f\n','Exogeneity tightness:     ',lambdas(4));
        fprintf(fid,'%15s %15.3f\n','Deterministic tightness : ',lambdas(5));
        fprintf(fid,'%15s %15.3f\n\n','Seasonal tightness :      ',lambdas(6));
    end
    fprintf(fid,'%20s %10.4f\n','Log Marginal Likelihood:       ',LogMargLike);
    fprintf(fid,'\n\n');

    for i=1:p
        w=0;
        fprintf(fid,'%15s %-20s','Endogenous:',varlabels{i});
        fprintf(fid,'%15s\n','');
        fprintf(fid,'%15s\n','');
        fprintf(fid,'%15s %15s %15s %15s\n',' ','Post. mean','Post Std. dev.','Post. t-value');
        for j=1:p
            for k=1:K
                w=w+1;
                fprintf(fid,'%15s %+15.4f %+15.4f %+15.4f\n',strcat(varlabels{j},'_',int2str(k)),P{i}(w,:)');
            end
        end
        for dumi=1:q
            w=w+1;
            fprintf(fid,'%15s %+15.4f %+15.4f %+15.4f\n',dummylabels{dumi},P{i}(w,:)');
        end
        fprintf(fid,'%15s\n','');
        fprintf(fid,'%20s %15.4f\n','Sigma for errors:',meansigma(i));
        fprintf(fid,'%15s\n','');
        fprintf(fid,'%15s\n','');
        fprintf(fid,'%15s\n','');
    end
    
    fprintf(fid,'%20s\n','Mean of contemporaneous coefficients - Upsilon');
    for jj=1:p
        fprintf(fid,'%10.4f',MeanUpsilon(jj,:));
        fprintf(fid,'%15s\n','');
    end
    fprintf(fid,'%15s\n','');
    fprintf(fid,'%20s\n','Stdev of contemporaneous coefficients - Upsilon');
    for jj=1:p
        fprintf(fid,'%10.4f',StdUpsilon(jj,:));
        fprintf(fid,'%15s\n','');
    end

    fclose(fid);
    winopen(strcat(OutFileName,'_Est','.txt'))
end
